#!/bin/tcsh

setenv COB_LIBRARY_PATH .
echo EXTENSIONS TEST GROUP
cat </dev/null > prog.empty

echo COMP-5
cp extensions.1 dump.c
c89 -Wc,dll,xplink,expo -Wl,dll,xplink -o dump.so dump.c >& comp.out
if ( $? != 0 ) goto err
cp extensions.2 prog.cob
cobc -x -debug -Wall -std=cobol2002 -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff extensions.3 result
if ( $? != 0 ) goto err

echo Hexadecimal numeric literal
cp extensions.4 prog.cob
cobc -x -debug -Wall -std=cobol2002 -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff extensions.5 result
if ( $? != 0 ) goto err

echo Semi-parenthesized condition
cp extensions.6 prog.cob
cobc -x -debug -Wall -std=cobol2002 -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff extensions.7 result
if ( $? != 0 ) goto err

echo ADDRESS OF
cp extensions.8 prog.cob
cobc -x -debug -Wall -std=cobol2002 -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff extensions.9 result
if ( $? != 0 ) goto err

echo LENGTH OF
cp extensions.10 prog.cob
cobc -x -debug -Wall -std=cobol2002 -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff extensions.11 result
if ( $? != 0 ) goto err

echo WHEN-COMPILED
cp extensions.12 prog.cob
cobc -x -debug -Wall -std=cobol2002 -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff extensions.13 result
if ( $? != 0 ) goto err

echo Complex OCCURS DEPENDING ON
cp extensions.14 prog.cob
cobc -x -debug -Wall -std=mvs -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff extensions.15 result
if ( $? != 0 ) goto err

echo MOVE NON-INTEGER TO ALPHA-NUMERIC
cp extensions.16 prog.cob
cobc -C -x -debug -Wall -std=mf prog.cob >& result
if ( $? != 0 ) goto err
diff extensions.17 result
if ( $? != 0 ) goto err
cobc -x -debug -Wall -std=mf prog.c >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff extensions.18 result
if ( $? != 0 ) goto err

echo CALL USING file-name
cp extensions.19 setfilename.c
cobc -m -debug -Wall -std=cobol2002 setfilename.c >& comp.out
if ( $? != 0 ) goto err
cp extensions.20 prog.cob
cobc -x -debug -Wall -std=cobol2002 -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff prog.empty result
if ( $? != 0 ) goto err
if ( ! -f TESTFILE ) goto err
rm TESTFILE setfilename.*

echo CALL unusual program-id.
cp extensions.21 A@B.cob
cobc -m -debug -Wall -std=cobol2002 A@B.cob >& comp.out
if ( $? != 0 ) goto err
cp extensions.22 A\#B.cob
cobc -m -debug -Wall -std=cobol2002 A\#B.cob >& comp.out
if ( $? != 0 ) goto err
cp extensions.23 A-B.cob
cobc -m -debug -Wall -std=cobol2002 A-B.cob >& comp.out
if ( $? != 0 ) goto err
cp extensions.24 A_B.cob
cobc -m -debug -Wall -std=cobol2002 A_B.cob >& comp.out
if ( $? != 0 ) goto err
cp extensions.25 caller.cob
cobc -x -debug -Wall -std=cobol2002 -o caller caller.cob >& comp.out
if ( $? != 0 ) goto err
caller > result
if ( $? != 0 ) goto err
diff prog.empty result
if ( $? != 0 ) goto err
rm A?B.*

echo ASSIGN MF
cp extensions.26 test.conf
cp extensions.27 prog.cob
cobc -x -debug -Wall -conf=test.conf -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff prog.empty result
if ( $? != 0 ) goto err

echo ASSIGN IBM
cp extensions.28 test.conf
cp extensions.29 prog.cob
cobc -x -debug -Wall -conf=test.conf -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff prog.empty result
if ( $? != 0 ) goto err
if ( ! -f FILENAME ) goto err
rm FILENAME

echo ASSIGN mapping
cp extensions.30 test.conf
cp extensions.31 prog.cob
cobc -x -debug -Wall -conf=test.conf -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
setenv DD_FILENAME x
prog
if ( $? != 0 ) goto err
if ( ! -f x ) goto err
unsetenv DD_FILENAME
setenv dd_FILENAME y
prog
if ( $? != 0 ) goto err
if ( ! -f y ) goto err
unsetenv dd_FILENAME
setenv FILENAME z
prog
if ( $? != 0 ) goto err
if ( ! -f z ) goto err
unsetenv FILENAME
prog
if ( $? != 0 ) goto err
if ( ! -f FILENAME ) goto err
rm FILENAME x y z

echo ASSIGN expansion
cp extensions.32 test.conf
cp extensions.33 prog.cob
cobc -x -debug -Wall -conf=test.conf -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
mkdir XXX
setenv DIR XXX
prog
if ( $? != 0 ) goto err
if ( ! -f XXX/FILENAME ) goto err
unsetenv DIR
rm XXX/FILENAME
rmdir XXX

echo ASSIGN with COB_FILE_PATH
cp extensions.53 test.conf
cp extensions.54 prog.cob
cobc -x -debug -Wall -conf=test.conf -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
mkdir XX2
setenv COB_FILE_PATH XX2
prog
if ( $? != 0 ) goto err
ls -l XX2
if ( ! -f XX2/FILENAMEX ) echo UNKNOWN FAILURE ... # goto err
(bash -c "export COB_FILE_PATH=XX2; ./prog")
if ( ! -f XX2/FILENAMEX ) echo UNKNOWN FAILURE ... # goto err
unsetenv COB_FILE_PATH
rm XX2/FILENAMEX
rmdir XX2

echo NUMBER-OF-CALL-PARAMETERS
cp extensions.34 callee.cob
cobc -m -debug -Wall -std=cobol2002 callee.cob >& comp.out
if ( $? != 0 ) goto err
cp extensions.35 caller.cob
cobc -x -debug -Wall -std=cobol2002 caller.cob >& comp.out
if ( $? != 0 ) goto err
caller > result
if ( $? != 0 ) goto err
diff extensions.36 result
if ( $? != 0 ) goto err

echo PROCEDURE DIVISION USING BY ...
cp extensions.37 callee.cob
cobc -m -debug -Wall -std=cobol2002 callee.cob >& comp.out
if ( $? != 0 ) goto err
cp extensions.38 caller.cob
cobc -x -debug -Wall -std=cobol2002 caller.cob >& comp.out
if ( $? != 0 ) goto err
caller > result
if ( $? != 0 ) goto err
diff extensions.39 result
if ( $? != 0 ) goto err

echo PROCEDURE DIVISION CHAINING ...
cp extensions.40 prog.cob
cobc -x -debug -Wall -std=cobol2002 -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog X ABCD > result
if ( $? != 0 ) goto err
diff extensions.41 result
if ( $? != 0 ) goto err

echo STOP RUN RETURNING
cp extensions.42 prog.cob
cobc -x -debug -Wall -std=cobol2002 prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 1 ) goto err
diff prog.empty result
if ( $? != 0 ) goto err

echo ENTRY
cp extensions.43 caller.cob
cobc -x -debug -Wall -std=mvs -c -fstatic-call caller.cob >& comp.out
if ( $? != 0 ) goto err
cp extensions.44 callee.cob
cobc -m -debug -Wall -std=mvs -c -fstatic-call callee.cob >& comp.out
if ( $? != 0 ) goto err
cobc -x -o prog caller.o callee.o >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff extensions.45 result
if ( $? != 0 ) goto err

echo LINE SEQUENTIAL write
cp extensions.46 prog.cob
cobc -x -debug -Wall -std=cobol2002 -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff prog.empty result
if ( $? != 0 ) goto err
if ( ! -f TEST-FILE ) goto err
diff extensions.47 TEST-FILE
if ( $? != 0 ) goto err
rm TEST-FILE

echo LINE SEQUENTIAL read
cp extensions.48 TEST-FILE
cp extensions.49 prog.cob
cobc -x -debug -Wall -std=cobol2002 -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog > result
if ( $? != 0 ) goto err
diff extensions.50 result
if ( $? != 0 ) goto err
rm TEST-FILE

echo ASSIGN to KEYBOARD/DISPLAY
cp extensions.55 TEST-FILE
cp extensions.56 prog.cob
cobc -x -debug -Wall -std=cobol2002 -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
prog < TEST-FILE > result
if ( $? != 0 ) goto err
diff TEST-FILE result
if ( $? != 0 ) goto err
rm TEST-FILE

echo Environment/Argument variable
cp extensions.51 prog.cob
cobc -x -debug -Wall -std=cobol2002 -o prog prog.cob >& comp.out
if ( $? != 0 ) goto err
setenv TEST_ENV OK
prog CHECKPAR > result
if ( $? != 0 ) goto err
diff extensions.52 result
if ( $? != 0 ) goto err

echo EXTENSIONS TEST PASSED
rm TESTFILE test.conf dump* caller* callee* prog* result comp.out
goto end

err:
	echo EXTENSIONS TEST FAILED
	exit(1)
end:
	exit(0)

